#mongo_client - A MongoDB driver for the Dart programming language.

Mongo Client (mongo_client) is a client library that aims to ease access to useful mongoDB operations. With Mongo Client you can easily perform common CRUD operations atop mongo_dart.

```dart 
var bankDb = new MongoClient('accounts', 'A-E');

bankDb
  .openDb()
  .then((_) {
    bankDb
      .findOne(where.match('customerName' : 'Julie'))
      .then((doc) {
        getAccountInfo(doc);
        bankDb.close();
      });
  });
```
Every CRUD operation has a convenience version that will automatically close the connection to database after completion.

```dart
var mongoQuery = where.gte('balance' : 100000).limit(500)

bankDb
  .openDbFind(mongoQuery)
  .then((docList) {
    for (Map doc in docList) {
      primerAccountRequest(doc['customerID']);
    }
  });
  .
```
Mongo Client also includes methods to help ease operations on a collection.

```dart 
DateTime currentTime = new DateTime.now().toUtc().toLocal();
var docList = [
  {'withdrawDate' :  currentTime},
  {'lastLogOut' :  currentTime},
];

bankDb
  .openDbInsertAll(docList, writeConcern: WriteConcern.ACKNOWLEDGED)
  .then((confirmMsg) {
    logIt(confirmMsg);
  });
```

###Useful Links:

- [mongo_dart repo](https://github.com/vadimtsushko/mongo_dart)

- [API Docs](http://www.dartdocs.org/documentation/mongo_dart/0.1.39)
 
###License
The MIT License (MIT)

Copyright (c) 2015 Eric Obodo

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
